@@ -231,6 +231,9 @@ enum {
 	FUNCTION_ID_KRONECKER_PRODUCT = 1141,
 	FUNCTION_ID_COLON = 1142,
 	FUNCTION_ID_FLIP = 1143,
+	FUNCTION_ID_REPLACE_PART = 1144,
+	FUNCTION_ID_CIRCSHIFT = 1145,
+	FUNCTION_ID_RESHAPE = 1146,
 	FUNCTION_ID_SQRT = 1200,
 	FUNCTION_ID_CBRT = 1201,
 	FUNCTION_ID_ROOT = 1202,
@@ -430,6 +433,8 @@ DECLARE_BUILTIN_FUNCTION(LimitsFunction, FUNCTION_ID_LIMITS)
 DECLARE_BUILTIN_FUNCTION(RankFunction, FUNCTION_ID_RANK)
 DECLARE_BUILTIN_FUNCTION(SortFunction, FUNCTION_ID_SORT)
 DECLARE_BUILTIN_FUNCTION(FlipFunction, FUNCTION_ID_FLIP)
+DECLARE_BUILTIN_FUNCTION(CircShiftFunction, FUNCTION_ID_CIRCSHIFT)
+DECLARE_BUILTIN_FUNCTION(ReshapeFunction, FUNCTION_ID_RESHAPE)
 DECLARE_BUILTIN_FUNCTION_M(ComponentFunction, FUNCTION_ID_COMPONENT)
 DECLARE_BUILTIN_FUNCTION_PI(DimensionFunction, FUNCTION_ID_DIMENSION)
 DECLARE_BUILTIN_FUNCTION(MatrixFunction, FUNCTION_ID_MATRIX)
@@ -438,6 +443,7 @@ DECLARE_BUILTIN_FUNCTION_M(HorzCatFunction, FUNCTION_ID_HORZCAT)
 DECLARE_BUILTIN_FUNCTION(MergeVectorsFunction, FUNCTION_ID_MERGE_VECTORS)
 DECLARE_BUILTIN_FUNCTION(MatrixToVectorFunction, FUNCTION_ID_MATRIX_TO_VECTOR)
 DECLARE_BUILTIN_FUNCTION(AreaFunction, FUNCTION_ID_AREA)
+DECLARE_BUILTIN_FUNCTION(ReplacePartFunction, FUNCTION_ID_REPLACE_PART)
 DECLARE_BUILTIN_FUNCTION_PI(RowsFunction, FUNCTION_ID_ROWS)
 DECLARE_BUILTIN_FUNCTION_PI(ColumnsFunction, FUNCTION_ID_COLUMNS)
 DECLARE_BUILTIN_FUNCTION(RowFunction, FUNCTION_ID_ROW)
