@@ -40,6 +40,8 @@ struct ExpressionName {
 	/// The name.
 	std::string name;
 
+	class ExpressionItem_p *priv;
+
 	/** Create an empty expression name. All properties are set to false.
 	*/
 	ExpressionName();
@@ -53,6 +55,9 @@ struct ExpressionName {
 	bool operator == (const ExpressionName &ename) const;
 	bool operator != (const ExpressionName &ename) const;
 
+	int underscoreRemovalAllowed() const;
+	std::string formattedName(int type, bool capitalize, bool html_suffix = false, int unicode_suffix = 0, bool remove_typename = false, bool hide_underscore = false, bool *was_formatted = NULL, bool *was_capitalized = NULL) const;
+
 };
 
 /// Abstract base class for functions, variables and units.
